from aishu.datafaker.anyrobot.getSqlVaule import AnyRobotDataServer
from aishu.datafaker.profession.getFiledValue import filed
from aishu import setting

class faker():
    def __init__(self,host,port,user,password,database):
        self.host = host
        self.port = port
        self.user = user
        self.password = password
        self.database = database
        setting.host = self.host
        setting.port = self.port
        setting.user = self.user
        setting.password = self.password
        setting.database = self.database

    def route(self,key,result=[]):
        date = AnyRobotDataServer(key).getValue()
        if isinstance(date, bool):
            date = filed(key, result)
            return date
        else:
            return date

if __name__ == '__main__':
    host = ''
    key = ''
    port = 3306
    user = ''
    password = ''
    database = ''
    date1 = faker(host,port,user,password,database).route(key)
    print(date1)


import jsonpath
import requests,json
from aishu import setting
from aishu.datafaker.profession.entity import id
from aishu.datafaker.profession.entity import name,timestamp,zx
from aishu.public.db_select import select


class search(object):
    def createSearchId(self):
        url = "http://{ip}/v1/search/submit".format(ip=setting.host)
        logGroup = id.date().getDefaultLogGroupID()
        payload = [
            {
                "logGroup": logGroup,
                "query": "*",
                "sort": [
                    {
                        "@timestamp": "desc"
                    }
                ],
                "size": 10,
                "needFieldList": True,
                "filters": {
                    "must": [
                        {
                            "@timestamp": {
                                "from": 1441001644796,
                                "to": 1598854444796
                            }
                        }
                    ],
                    "must_not": []
                }
            }
        ]
        headers = setting.header

        rsp = requests.request("POST", url, headers=headers, data = json.dumps(payload))
        s_id = jsonpath.jsonpath(rsp.json(), '$..{name}'.format(name='id'))
        if isinstance(s_id,bool):
            return False
        else:
            return s_id[0]

    def createInspectionID(self):
        url = "http://{ip}/manager/inspections/inspection".format(ip=setting.host)
        assigned = id.date().getAdminID()
        number = name.date().getName()
        time = timestamp.date().getStartTime()
        payload = {
                "assign": assigned,
                "name": number,
                "info": "This is a test case by AT",
                "ctime": time
        }
        headers = setting.header

        rsp = requests.request("POST", url, headers=headers, data = json.dumps(payload))
        InspectionID = jsonpath.jsonpath(rsp.json(), '$..{name}'.format(name='id'))
        if isinstance(InspectionID,bool):
            return False
        else:
            return InspectionID[0]

    def createInspectionTaskID(self):
        url = "http://{ip}/manager/inspections/task".format(ip=setting.host)
        InspectionID = zx.search().createInspectionID()
        number = name.date().getName()
        payload = {

                "name": number,
                "position": "localUpload",
                "info": "step one: find the target page ；step two：write the check result",
                "inspectionID": InspectionID
        }
        headers = setting.header

        rsp = requests.request("POST", url, headers=headers, data = json.dumps(payload))
        InspectionTaskID = jsonpath.jsonpath(rsp.json(), '$..{name}'.format(name='id'))
        if isinstance(InspectionTaskID,bool):
            return False
        else:
            return InspectionTaskID[0]

    def createExportFileID(self):
        url = "http://{ip}/manager/export".format(ip=setting.host,id=zx.search().createSearchId())
        start = timestamp.date().getLastFiveYearTime()
        end = timestamp.date().getStartTime()
        user = id.date().getAdminID()
        loggroup = id.date().getDefaultLogGroupID()
        payload = {
                "logtype": "list",
                "filename": "列表",
                "timezone": 8,
                "user": user,
                "fileType": "txt",
                "fileCode": "UTF-8",
                "query": [
                    {
                        "logGroup": loggroup,
                        "query": "*",
                        "size": 207,
                        "needFieldList": True,
                        "filters": {
                            "must": [
                                {
                                    "@timestamp": {
                                        "from": start,
                                        "to": end
                                    }
                                }
                            ],
                            "must_not": []
                        }
                    }
                ],
                "fields": [
                    "_source"
                ],
                "indexs": [
                    "fe5b7f96-443a-11e7-a467-000c29253e90"
                ]
        }
        headers = setting.header
        rsp = requests.request("POST", url, headers=headers, data=json.dumps(payload))
        ExportFileID = jsonpath.jsonpath(rsp.json(), '$..{name}'.format(name='id'))
        if isinstance(ExportFileID, bool):
            return False
        else:
            return ExportFileID[0]

    def getRepeatInspectionName(self):
        sql = 'select name from Inspection'
        sqldata = select(sql)
        if not (sqldata):
            return False

        return sqldata[0][0]

    # def getOrdinaryID(self):
    #     sql = 'select userId from `User` where loginName!="admin"'
    #     sqldata = select(sql)
    #     if not (sqldata):
    #         return False
    #
    #     return sqldata[0][0]

if __name__ == '__main__':
    setting.host = "192.168.84.84"
    setting.database = 'AnyRobot'
    setting.password = 'eisoo.com'
    setting.port = 30006
    setting.user = 'root'
    date = search().getOrdinaryID()
    print(date)



# !/usr/bin/env python
# -*- coding: UTF-8 -*-
from aishu.datafaker.profession.entity import port
from aishu.datafaker.profession.entity import ip
import requests
import time

class Port(object):
    def __init__(self):
        pass

    def httpport(self):
        url = 'http://{ip}/etl/input'.format(ip=ip.date().getTestHostIP)
        http_port = port.date().getEtlPortNew
        body = {
            "community":[],
            "port":http_port,
            "agentProtocol":"HTTP",
            "protocol":"AR-Agent",
            "ruleName":None,
            "status":1,
            "type":None,
            "tagsID":[],
            "tags":[],
            "timezone":"Asia/Shanghai",
            "charset":"UTF-8"
        }
        requests.post(url=url, json= body)
        time.sleep(1)
        print(http_port)
        return http_port

    def syslogPort(self):
        url_syslog = 'http://{ip}/etl/input'.format(ip=ip.date().getTestHostIP)
        syslog_port = port.date().getEtlPortNew
        body_syslog = {
            "community":[],
            "port": syslog_port,
            "protocol":"syslog",
            "ruleName":None,
            "status":1,
            "tagsID":[],
            "tags":[],
            "timezone":"Asia/Shanghai",
            "type":"syslog",
            "charset":"UTF-8"
        }
        requests.post(url=url_syslog, json= body_syslog)
        time.sleep(60)
        print(syslog_port)
        return syslog_port




from aishu import setting

def sql(key):
    """
    对应数据服务的sql语句注册
    :param key:
    :return:
    """
    switcher = {
        'UserID':{'sql':'select userId from User where loginName = "admin";','database':'AnyRobot'},
        'MLID': {'sql': "select id from MLJob ;", 'database': 'AnyRobotML'},
        'entityID': {'sql': "select id from KAIEntity;", 'database': 'AnyRobot'},
        'groupID': {'sql': "select id from KAIEntityGroup;", 'database': 'AnyRobot'},
        'AlertRuleID': {'sql': "select id from RuleEngineAlert;", 'database': 'AnyRobot'},
        'kpiID': {'sql': "select id from KAIKpi;", 'database': 'AnyRobot'},
        'LogTypeID': {'sql': "select dataType from LogWareHouse;", 'database': 'AnyRobot'},
        'AddEntityID': {
            'sql': "select entityId from KAIEntityCondition where conditionValues = '192.168.84.26' AND conditionKeys = 'host';",
            'database': 'AnyRobot'},
        'KpiTemplateID': {'sql': "select id from KAIKpiTemplate;", 'database': 'AnyRobot'},
        'KpiTemplateID1': {'sql': "select id from KAIKpiTemplate;", 'database': 'AnyRobot'},
        'KpiTemplateID2': {'sql': "select id from KAIKpiTemplate;", 'database': 'AnyRobot'},
        'logWareHouseID': {'sql': "SELECT id From LogWareHouse where LENGTH(id)!=8;", 'database': 'AnyRobot'},
        'logWareHouseId': {'sql': "SELECT id From LogWareHouse where LENGTH(id)!=8;", 'database': 'AnyRobot'},
        'wareHouseName': {'sql': "SELECT wareHouseName From LogWareHouse;", 'database': 'AnyRobot'},
        'dataType': {'sql': "SELECT dataType From LogWareHouse where LENGTH(id)!=8;", 'database': 'AnyRobot'},
        'indexID': {'sql': "SELECT id From IndexParams;", 'database': 'AnyRobot'},
        'indexName': {'sql': "SELECT indexName From IndexParams;", 'database': 'AnyRobot'},
        'StreamId': {'sql': "SELECT id From DataStream;", 'database': 'AnyRobot'},
        'LogGroupIdPare': {'sql': 'SELECT groupId From LogGroup where GroupName!="所有日志";', 'database': 'AnyRobot'},
        'RoleId': {'sql': 'SELECT roleId From Role where roleName ="admin";', 'database': 'AnyRobot'},
        'tagGroupID': {'sql': "SELECT id From TagGroup;", 'database': 'AnyRobot'},
        'tagID': {'sql': "SELECT id From Tag;", 'database': 'AnyRobot'},
        'HostID': {'sql': "SELECT id From AgentHost;", 'database': 'AnyRobot'},
        'HostIp': {'sql': "SELECT ip From AgentHost;", 'database': 'AnyRobot'},
        'openapiID': {'sql': "SELECT id From OpenAPIManager;", 'database': 'AnyRobotOpenLog'},
        'UserID_Notadmin': {'sql': 'select userId from User where loginName != "admin";', 'database': 'AnyRobot'},

        'JDBCCollectorId': {
            'sql': "select collectorId from JDBCCollectorConfig where JDBCCollectorConfig.type='jdbc' AND JDBCCollectorConfig.`sql`='select * from CollectorConfig';",
            'database': 'AnyRobot'},
        'vSphereID': {
            'sql': "SELECT collectorId FROM CollectorConfig WHERE collectorType='vSphere' AND config LIKE '%192.168.0.250%';",
            'database': 'AnyRobot'},
        'vcenterCollectorId': {
            'sql': "SELECT collectorId FROM CollectorConfig WHERE collectorType='vCenter' AND config LIKE '%192.168.0.250%';",
            'database': 'AnyRobot'},
        'MySQLCollectorId': {'sql': "SELECT collectorId FROM CollectorConfig WHERE collectorType='MySQL Performance';",
                             'database': 'AnyRobot'},
        'OracleCollectorId': {
            'sql': "SELECT collectorId FROM CollectorConfig WHERE collectorType='Oracle Performance';",
            'database': 'AnyRobot'},
        'AIXCollectorId': {'SQL': "SELECT collectorId FROM CollectorConfig WHERE collectorType='AIX Errpt';",
                           'database': 'AnyRobot'},
        'CMDCollectorId': {'sql': "SELECT collectorId FROM CollectorConfig WHERE collectorType='Command Result';",
                           'database': 'AnyRobot'},
        'CollectorId': {'sql': "SELECT collectorId FROM CollectorConfig;", 'database': 'AnyRobot'},
        'DBConnectID': {'sql': "SELECT id FROM DBConnect;", 'database': 'AnyRobot'},
        'AuthID': {'sql': "SELECT id FROM AgentHostAuth;", 'database': 'AnyRobot'},
        'authName': {'sql': "SELECT `name` FROM AgentHostAuth;", 'database': 'AnyRobot'},
        'TemplateID': {'sql': "SELECT id FROM AgentConfigTemplate;", 'database': 'AnyRobot'},
        'AgentInputTemplateID': {'sql': "SELECT id FROM AgentConfigTemplate WHERE category='input';",
                                 'database': 'AnyRobot'},
        'AgentOutTemplateID': {'sql': "SELECT id FROM AgentConfigTemplate WHERE category='output';",
                               'database': 'AnyRobot'},
        'InputTemplateName': {'sql': "SELECT `name` FROM AgentConfigTemplate WHERE category='input';",
                              'database': 'AnyRobot'},
        'OutputTemplateName': {'sql': "SELECT `name` FROM AgentConfigTemplate WHERE category='output';",
                               'database': 'AnyRobot'},
        'AgentGroupID': {'sql': "SELECT id FROM AgentGroup;", 'database': 'AnyRobot'},
        'AgentJobTemplateID': {'sql': "SELECT id FROM AgentJobTemplate", 'database': 'AnyRobot'},
        'JobID': {'sql': "SELECT id FROM AgentJobInfo;", 'database': 'AnyRobot'},
        'uploadID': {'sql': "SELECT id FROM Upload;", 'database': 'AnyRobot'},
        'uninstallHostID': {'sql':"SELECT id From AgentHost WHERE ip='10.4.15.54';",'database': 'AnyRobot'},
        'entitygroupId': {'sql':"SELECT id From KAIEntityGroup ;",'database': 'AnyRobot'},
        'serviceKpiId': {'sql':"SELECT id From KAIKpi ;",'database': 'AnyRobot'},
        'serviceHeathId': {'sql':"SELECT serviceId From KAIHealth ;",'database': 'AnyRobot'},
        'KAIAlertId': {'sql':"SELECT id From KAIAlert ;",'database': 'AnyRobot'},
        'KAIBusinessId': {'sql':"SELECT id From KAIBusiness ;",'database': 'AnyRobot'},
        'graphName': {'sql':"SELECT graph_name From graph ;",'database': 'AnyRobot'},
        'ScheduleTaskId': {'sql':"SELECT id From ScheduleTask ;",'database': 'AnyRobot'},
        'ScheduleTaskId1': {'sql':"SELECT id From ScheduleTask ;",'database': 'AnyRobot'},
        'UserId': {'sql':"SELECT userId From User ;",'database': 'AnyRobot'},
        'UserId2': {'sql':"SELECT userId From User ;",'database': 'AnyRobot'},
        'alertLogId': {'sql':"SELECT alert_scenario_rule_id From RuleEngineAlertLog ;",'database': 'AnyRobot'}
    }

    if switcher.get(key) is not None:
        if switcher[key].get('database') is not None:
            if len(switcher[key]['database']) == 0:
                setting.database = 'AnyRobot'
            else:
                setting.database = switcher[key]['database']

        return switcher[key]['sql']
    else:
        return False
